@@ -104,9 +104,9 @@ AbstractType::Ptr TypeBuilder::parseSimpleType(QString type, AstNode* node)
             return AbstractType::Ptr(new IntegralTypeExtended(IntegralTypeExtended::TypeObject));
         }
 
-        QualifiedIdentifier typehint = QualifiedIdentifier(type.toLower().replace(QLatin1Literal("\\"), QLatin1Literal("::")));
+        QualifiedIdentifier typehint = QualifiedIdentifier(type.toLower().replace(QLatin1String("\\"), QLatin1String("::")));
 
-        if (typehint.toString().startsWith(QLatin1Literal("::"))) {
+        if (typehint.toString().startsWith(QLatin1String("::"))) {
             typehint.setExplicitlyGlobal(true);
         }
 
@@ -142,7 +142,7 @@ AbstractType::Ptr TypeBuilder::injectParseType(QString type, AstNode* node)
  *
  *  /// @docCommentName value
  */
-QStringList findInDocComment(const QString &docComment, const QString &docCommentName, const bool onlyOne)
+static QStringList findInDocComment(const QStringView &docComment, const QString &docCommentName, const bool onlyOne)
 {
     QStringList matches;
     // optimization that does not require potentially slow regexps
@@ -162,7 +162,7 @@ QStringList findInDocComment(const QString &docComment, const QString &docCommen
         if ( docComment[i].isSpace() || docComment[i] == '*' || docComment[i] == '/' ) {
             // skip whitespace and comment-marker at beginning of line
             continue;
-        } else if ( docComment[i] == '@' && docComment.midRef(i + 1, docCommentName.size()) == docCommentName ) {
+        } else if ( docComment[i] == '@' && docComment.mid(i + 1, docCommentName.size()) == docCommentName ) {
             // find @return or similar
             i += docCommentName.size() + 1;
             // skip whitespace (at least one is required)
@@ -186,7 +186,7 @@ QStringList findInDocComment(const QString &docComment, const QString &docCommen
                 ++pos;
             }
             if ( pos > i ) {
-                matches << docComment.mid(i, pos - i);
+                matches << docComment.mid(i, pos - i).toString();
                 if ( onlyOne ) {
                     break;
                 } else {
@@ -403,6 +403,16 @@ void TypeBuilder::visitParameter(ParameterAst *node)
 
     AbstractType::Ptr type = parameterType(node, phpDocTypehint, editor(), currentContext());
 
+    if (node->defaultValue) {
+        QString symbol = m_editor->parseSession()->symbol(node->defaultValue);
+
+        if (node->parameterType && node->parameterType->typehint &&
+                symbol.compare(QLatin1String("null"), Qt::CaseInsensitive) != 0 &&
+                type->contains(new IntegralTypeExtended(IntegralTypeExtended::TypeObject))) {
+            reportError(i18n("Default value for parameters with an object type can only be NULL."), node->defaultValue);
+        }
+    }
+
     openAbstractType(type);
     TypeBuilderBase::visitParameter(node);
     closeType();
